@@ -28,7 +28,7 @@ DISPLAY OPTIONS
   -w, --width COLS   set screen width in columns
 
 FILTERING AND SORTING OPTIONS
-  -a, --all                  show hidden and 'dot' files
+  -a, --all                  show hidden and 'dot' files. Use this twice to also show the '.' and '..' directories
   -d, --list-dirs            list directories as files; don't list their contents
   -L, --level DEPTH          limit the depth of recursion
   -r, --reverse              reverse the sort order
